==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Visual/analyzer/translations/analyzer_plugin_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="47"/>
        <source>Qmmp Analyzer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="356"/>
        <source>Peaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="359"/>
        <source>Refresh Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="362"/>
        <source>50 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="363"/>
        <source>25 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="364"/>
        <source>10 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="365"/>
        <source>5 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="372"/>
        <source>Analyzer Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="375"/>
        <location filename="../analyzer.cpp" line="389"/>
        <source>Slowest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="376"/>
        <location filename="../analyzer.cpp" line="390"/>
        <source>Slow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="377"/>
        <location filename="../analyzer.cpp" line="391"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="378"/>
        <location filename="../analyzer.cpp" line="392"/>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="379"/>
        <location filename="../analyzer.cpp" line="393"/>
        <source>Fastest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="386"/>
        <source>Peaks Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="400"/>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="400"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="31"/>
        <source>Analyzer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>About Analyzer Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Visual/analyzer/translations/analyzer_plugin_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>Analyzer</name>
    <message>
        <location filename="../analyzer.cpp" line="44"/>
        <source>Qmmp Analyzer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="332"/>
        <source>Peaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="335"/>
        <source>Refresh Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="338"/>
        <source>50 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="339"/>
        <source>25 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="340"/>
        <source>10 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="341"/>
        <source>5 fps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="348"/>
        <source>Analyzer Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="351"/>
        <location filename="../analyzer.cpp" line="365"/>
        <source>Slowest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="352"/>
        <location filename="../analyzer.cpp" line="366"/>
        <source>Slow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="353"/>
        <location filename="../analyzer.cpp" line="367"/>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="354"/>
        <location filename="../analyzer.cpp" line="368"/>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="355"/>
        <location filename="../analyzer.cpp" line="369"/>
        <source>Fastest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="362"/>
        <source>Peaks Falloff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="376"/>
        <source>&amp;Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../analyzer.cpp" line="376"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorWidget</name>
    <message>
        <location filename="../colorwidget.cpp" line="37"/>
        <source>Select Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Analyzer Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Cells size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="101"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Peaks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="139"/>
        <source>Analyzer #1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="171"/>
        <source>Background:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="203"/>
        <source>Analyzer #2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Analyzer #3:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VisualAnalyzerFactory</name>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="31"/>
        <source>Analyzer Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="50"/>
        <source>About Analyzer Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="51"/>
        <source>Qmmp Analyzer Visual Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../visualanalyzerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
